@@ -10,7 +10,7 @@
 # Note:
 # none
 #
-# Copyright (c) 2012-2017, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2018, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 use warnings;
@@ -125,10 +125,9 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0036   => "DB cluster version ([0]) does not match the PostgreSQL version ([1]).\n",
     SLAVESTART_MS0037   => "Database identifier on this node is different from another ([0] != [1]).\n",
     SLAVESTART_MS0038   => "TimeLineID on this node is larger than another ([0] > [1]).\n",
-    SLAVESTART_MS0039   => "Could not find wal file on this node: [0]\n",
     SLAVESTART_MS0040   => "Could not find wal file on another node: [0]\n",
     SLAVESTART_MS0041   => "This node is advancing in XLOG location against the peer node ([0] > [1]).\n",
-    SLAVESTART_MS0042   => "No timeline history files found on another node.\n",
+    SLAVESTART_MS0042   => "Could not find latest history file on another node: [0]\n",
     SLAVESTART_MS0043   => "There are no history that has passed through TimeLineID on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
     SLAVESTART_MS0044   => "There are no history that has passed through the location of xlog on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
     SLAVESTART_MS0045   => "This node needs to be reinitialized from a new base backup.\n",
@@ -165,7 +164,13 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0074   => "pg_rewind failed to connect to the peer\n - TCP Forwarding may be disabled in sshd_config on the peer server\n",
     SLAVESTART_MS0075   => "This database cluster is incompletely rewinded by pg-rex_slave_start.\n",
     SLAVESTART_MS0076   => "WAL files with future XLOG location of the peer node found in archive directory.\n",
-    SLAVESTART_MS0087   => "Timeline hitory file for timeline ID [0] not found on another node: [1]\n",
+    SLAVESTART_MS0077   => "Skip synchronizing the archive directory because slave's archive directory is newer than master.\n",
+    SLAVESTART_MS0078   => "The archive log \"[0]\" that synchronize is incomplete.\n",
+    SLAVESTART_MS0079   => "The archive log \"[0]\" is unexpected extension (Unexpected extension: [1]).\nSkipping the integrity check of the archive log.\n",
+    SLAVESTART_MS0080   => "WAL directory of the base backup is not empty.\n",
+    SLAVESTART_MS0081   => "Master's archive directory has WAL that is advancing than current LSN of the master node.\n",
+    SLAVESTART_MS0082   => "--options and PG_BASEBACKUP_opt(pg-rex_tools.conf) is ignore.\n",
+    SLAVESTART_MS0083   => "WAL file of pg_wal is inappropriate. If start the Slave on this state, archive log will be lost.\n",
     SLAVESTART_MS0099   => "Internal Error.\n",
 
     STOP_USAGE  => <<_STOP_USAGE_,
@@ -306,7 +311,6 @@ _SWITCHOVER_USAGE_
     SWITCHOVER_MS0013   => "In addition, There are multi standby on the node ([0]).\n",
     SWITCHOVER_MS0014   => "Do you want to continue ? (y/N) ",
     SWITCHOVER_MS0015   => "Exit.\n",
-    SWITCHOVER_MS0016   => "[0]. Executing vacuumdb command.\n",
     SWITCHOVER_MS0017   => "[0]. Executing CHECKPOINT.\n",
     SWITCHOVER_MS0018   => "**** Execute to switchover ****\n",
     SWITCHOVER_MS0019   => "[0]. Stopping monitoring by Pacemaker.\n",
@@ -365,7 +369,7 @@ _SWITCHOVER_USAGE_
     COMMON_MS0036       => "Not found PostgreSQL commands in specified PGPATH ([0]).\n".
                            "Should specify PGPATH correctly in pg-rex_tools.conf.\n",
     COMMON_MS0037       => "PostgreSQL [0] is not supported.\n".
-                           "Please use version 9.5 or 9.6.\n",
+                           "Please use version 10.\n",
     COMMON_MS0038       => "Pacemaker [0] is not supported.\n".
                            "Please use version 1.1.\n",
     COMMON_MS0039       => "Not found network interface to correspond to bindnetaddr ([1]) on [0].\n",
@@ -381,7 +385,6 @@ _SWITCHOVER_USAGE_
     COMMON_MS0049       => "[0] has already started on this node.\n",
     COMMON_MS0050       => "Failed to create lock file([0]).\n",
     COMMON_MS0051       => "Failed to delete lock file([0]). : [1]\n",
-    COMMON_MS0052       => "[0] is not in IPv4 format.\n",
 };
 
 1;
