@@ -10,7 +10,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2017, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2018, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 use warnings;
@@ -128,7 +128,6 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0036   => "DB クラスタのバージョン ([0]) が PostgreSQL サーバのバージョン ([1]) と一致していません\n",
     SLAVESTART_MS0037   => "自身のノードと相手のノードでデータベース識別子が異なっています ([0] != [1])\n",
     SLAVESTART_MS0038   => "自身のノードの タイムラインID のほうが相手のノードの タイムラインID よりも大きくなっています ([0] > [1])\n",
-    SLAVESTART_MS0039   => "自身のノードに WAL ファイルが存在しません: [0]\n",
     SLAVESTART_MS0040   => "相手のノードに WAL ファイルが存在しません: [0]\n",
     SLAVESTART_MS0041   => "自身のノードの XLOG の位置のほうが相手のノードの XLOG の位置よりも進んでいます ([0] > [1])\n",
     SLAVESTART_MS0042   => "相手のノードに最新のタイムライン履歴ファイルが存在しません: [0]\n",
@@ -168,6 +167,13 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0074   => "pg_rewind が相手のノードへの接続に失敗しました\n - 相手ノードの sshd_config で TCP Forwarding が無効になっている可能性があります\n",
     SLAVESTART_MS0075   => "pg-rex_slave_startで巻き戻しに失敗したDBクラスタです。\n",
     SLAVESTART_MS0076   => "アーカイブディレクトリに相手のノードの XLOG の位置よりも進んだ WAL ファイルが存在します\n",
+    SLAVESTART_MS0077   => "Slave のアーカイブディレクトリのほうが新しいため、同期をスキップします\n",
+    SLAVESTART_MS0078   => "アーカイブログ \"[0]\" が不完全であるため、スクリプトを終了します\n",
+    SLAVESTART_MS0079   => "アーカイブログ \"[0]\" の拡張子が未知のため、完全性が確認できませんでした (未知の拡張子: [1])\n完全性の確認をスキップします\n",
+    SLAVESTART_MS0080   => "WAL ファイルが存在するため、スクリプトを終了します\n",
+    SLAVESTART_MS0081   => "Master のアーカイブディレクトリに Master の現在の LSN よりも進んだ WAL ファイルが存在します\n",
+    SLAVESTART_MS0082   => "--optionsまたはPG_BASEBACKUP_opt(pg-rex_tools.conf)の設定は無視します\n",
+    SLAVESTART_MS0083   => "pg_wal の WAL ファイルの状態が不適切です。このまま Slave を起動するとアーカイブログが欠損するためスクリプトを終了します\n",
     SLAVESTART_MS0099   => "内部エラー\n",
 
     STOP_USAGE  => <<_STOP_USAGE_,
@@ -310,7 +316,6 @@ _SWITCHOVER_USAGE_
     SWITCHOVER_MS0013   => "また、現在 [0] に複数の Slave が存在しています\n",
     SWITCHOVER_MS0014   => "系切り替えを実行してもよろしいでしょうか？ (y/N) ",
     SWITCHOVER_MS0015   => "スクリプトを終了します\n",
-    SWITCHOVER_MS0016   => "[0]. vacuumdb コマンドの実行\n",
     SWITCHOVER_MS0017   => "[0]. CHECKPOINT の実行\n",
     SWITCHOVER_MS0018   => "**** 系切り替えを実行 ****\n",
     SWITCHOVER_MS0019   => "[0]. Pacemaker の監視を停止\n",
@@ -362,14 +367,14 @@ _SWITCHOVER_USAGE_
     COMMON_MS0030       => "\nパスワードが入力されました\n",
     COMMON_MS0031       => "パスワードファイル \"[0]\" が存在しません\n",
     COMMON_MS0032       => "パスワードファイル \"[0]\" の読み込みに失敗しました\n",
-    COMMON_MS0033       => "SSHパスワードが不正です\n",
+    COMMON_MS0033       => "パスワードファイル \"[0]\" の内容が不正です\n",
     COMMON_MS0034       => "環境設定ファイル (pg-rex_tools.conf) の [0] の設定は、\n".
                            "manual、passfile、nopass のいずれかを指定してください\n",
     COMMON_MS0035       => "パスワードファイル \"[0]\" の権限が 600 ではありません\n",
     COMMON_MS0036       => "指定された PGPATH ([0]) に PostgreSQL コマンドが存在しません\n".
                            "環境設定ファイル (pg-rex_tools.conf) の PGPATH を環境にあわせて設定してください\n",
     COMMON_MS0037       => "PostgreSQL [0] には対応していません\n".
-                           "PostgreSQL 9.4 または 9.5 を使用してください\n",
+                           "PostgreSQL 10 を使用してください\n",
     COMMON_MS0038       => "Pacemaker [0] には対応していません\n".
                            "Pacemaker 1.1 を使用してください\n",
     COMMON_MS0039       => "[0] で bindnetaddr ([1]) に対応するネットワークインタフェースが見つかりませんでした\n",
@@ -379,6 +384,12 @@ _SWITCHOVER_USAGE_
     COMMON_MS0043       => "相手のノードで ifcheckd が停止しています\n",
     COMMON_MS0044       => "アーカイブディレクトリの状態を確認できませんでした: [0]\n",
     COMMON_MS0045       => "バックアップラベルファイルの一行目のフォーマットが正しくありません: [0]\n",
+    COMMON_MS0046       => "DBクラスタの状態確認に失敗しました。: [0]\n",
+    COMMON_MS0047       => "DBクラスタにアクセス中のプロセスが存在します。\n[0]",
+    COMMON_MS0048       => "ロックファイル([0])の作成に失敗しました。: [1]\n",
+    COMMON_MS0049       => "自身のノードで [0] が稼働しています。起動処理を中止します。\n",
+    COMMON_MS0050       => "ロックファイル([0])の作成に失敗しました。\n",
+    COMMON_MS0051       => "ロックファイル([0])の削除に失敗しました。: [1]\n",
 };
 
 1;
