@@ -8,7 +8,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2017, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2018, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 package PGRex;
@@ -46,7 +46,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "1.8.3",
+    VERSIONNUM       => "10.0",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -524,7 +524,7 @@ sub read_config{
     $config_value{'VIP_SLAVE'} = "enable";
     $config_value{'PEER_NODE_SSH_PASS_MODE'} = "manual";
     $config_value{'BACKUP_NODE_SSH_PASS_MODE'} = "manual";
-    $config_value{'PG_BASEBACKUP_opt'} = "-X stream";
+    $config_value{'PG_BASEBACKUP_opt'} = "";
     
     open (FILE, $config_path) or printlog("ERROR", COMMON_MS0024, $config_path);
     @config_strings = <FILE>;
@@ -826,7 +826,7 @@ sub ssh_exec_command {
 
 
 sub rsync_exec_command {
-    my ($ssh_info, $remote, $local, $put_flag) = @_; 
+    my ($ssh_info, $options, $remote, $local, $put_flag) = @_; 
     my $ssh;
 
     if ($ssh_info->pass() eq ""){
@@ -838,10 +838,15 @@ sub rsync_exec_command {
     $ssh->error and printlog("ERROR", COMMON_MS0016);
 
     my %opts = (
-        archive => 1,
-        verbose => 1,
+        'archive' => 1,
+        'verbose' => 1,
+        'size-only' => 1,
     );
 
+    if (defined($options)) {
+        %opts = (%opts, %{$options});
+    }
+
 	if ($put_flag){
 		$ssh-> rsync_put(\%opts, $local, $remote) or $ssh->error and printlog("ERROR", COMMON_MS0017);
 	}
@@ -1040,12 +1045,11 @@ sub get_node{
 }
 
 
-sub get_pg_version{
+sub get_pg_version_num {
     my ($postgres_path, $exec_user) = @_;
     my $result;
-    my @results;
-    my @version_factor;
     my $pg_command_user = "postgres";
+    my $version_num;
 
     if (defined($exec_user) && $exec_user ne "root"){
         $result = exec_command("$postgres_path --version");
@@ -1053,24 +1057,38 @@ sub get_pg_version{
         $result = exec_command("$SU - $pg_command_user -c  \"$postgres_path --version\"");
     }
 
-    @results = split(/\s/,$result);
-    chomp $results[2];
-
-    @version_factor = split(/\./,$results[2]);
-
-    if (@version_factor == 2){
-        if ($version_factor[1] =~ /(^\d+)\D+/){
-            $version_factor[1] = $1;
-            $version_factor[2] = "0";
+    $result =~ /(\d+)(?:[^\.]+)?(?:\.(\d+)(?:[^\.]+)?)?(?:\.(\d+))?$/;
+    if ($1 eq 10){
+        # PostgreSQL 10の場合
+        # $1 : Major Version
+        # $2 : Minor Version
+        # $2が未定義の場合は、betaまたはrc版
+        if (!defined($2)){
+            $version_num = 10000 * $1;
+        }
+        else{
+            $version_num = 10000 * $1 + $2;
         }
     }
-
-    return sprintf("%s.%s.%s", $version_factor[0], $version_factor[1], $version_factor[2]);
+    else{
+        # PostgreSQL 9.6以下の場合
+        # $1.$2 : Major Version
+        # $3    : Minor Version
+        # $3が未定義の場合は、betaまたはrc版
+        if (!defined($3)){
+            $version_num = 100 * (100 * $1 + $2);
+        }
+        else{
+            $version_num = 100 * (100 * $1 + $2) + $3;
+        }
+    }
+    return $version_num;
 }
 
 sub check_support_version {
     my ($postgres_path, $exec_user) = @_;
     my @version_factor;
+    my $version_num;
 
     # Pacemaker がサポート対象バージョンであるかを確認する
     @version_factor = split(/\./, get_pm_version());
@@ -1079,10 +1097,14 @@ sub check_support_version {
     }
 
     # PostgreSQL がサポート対象バージョンであるかを確認する
-    @version_factor = split(/\./, get_pg_version($postgres_path, $exec_user));
-    if ($version_factor[0] != 9 ||
-        ($version_factor[1] != 5 && $version_factor[1] != 6)){
-            printlog("ERROR", COMMON_MS0037, get_pg_version($postgres_path), $exec_user);
+    $version_num = get_pg_version_num($postgres_path, $exec_user);
+    if (int($version_num / 10000) ne 10){
+        if ($version_num >= 100000) {
+            printlog("ERROR", COMMON_MS0037, int($version_num / 10000));
+        } else {
+            printlog("ERROR", COMMON_MS0037, sprintf("%d.%d",
+                int($version_num / 10000), int(($version_num / 100) % 100)));
+        }
     }
 }
 
@@ -1107,7 +1129,7 @@ sub ifcheckd_running {
 sub get_pg_command_path {
     my ($pg_path, $exec_user) = @_;
     my %command_path;
-    my @command_list = ("postgres", "psql", "pg_controldata", "pg_basebackup", "vacuumdb", "pg_xlogdump", "pg_rewind", "pg_ctl");
+    my @command_list = ("postgres", "psql", "pg_controldata", "pg_basebackup", "pg_waldump", "pg_rewind", "pg_ctl");
     my $pg_command_user = "postgres";
 
     if (!$pg_path){
